controller property
Controller that supplies the current page and, when non-null, the items.
Implementation
final KFDrawerController? controller;
Controller that supplies the current page and, when non-null, the items.
final KFDrawerController? controller;