replacePage method
Displays value without adding the current page to history.
Implementation
void replacePage(Widget? value) {
if (identical(_page, value)) {
return;
}
_page = value;
notifyListeners();
}
Displays value without adding the current page to history.
void replacePage(Widget? value) {
if (identical(_page, value)) {
return;
}
_page = value;
notifyListeners();
}